From 906032b5ea4b281ac8c48b3a6e0d9f6509ee5f6c Mon Sep 17 00:00:00 2001
From: jach11 <jach11@users.noreply.github.com>
Date: Sun, 21 Aug 2016 05:28:28 -0400
Subject: [PATCH] Fix incorrect spelling

Correct the incorrect spelling of dependencies
---
 lgsm/functions/check_deps.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/lgsm/functions/check_deps.sh b/lgsm/functions/check_deps.sh
index 57f432ec4..6ccde762c 100644
--- a/lgsm/functions/check_deps.sh
+++ b/lgsm/functions/check_deps.sh
@@ -120,7 +120,7 @@ fn_check_loop(){
 		fn_deps_detector
 	done
 
 	# user to be informaed of any missing dependecies
 	fn_found_missing_deps
 }
 
@@ -128,7 +128,7 @@ info_distro.sh
 
 if [ "${function_selfname}" == "command_install.sh" ]; then
 	echo ""
-	echo "Checking Dependecies"
+	echo "Checking Dependencies"
 	echo "================================="
 fi
@@ -120,7 +120,7 @@ fn_check_loop(){
 	done
 
-	# user to be informaed of any missing dependecies
+	# user to be informaed of any missing dependencies
 	fn_found_missing_deps
 }